# Title of Dataset:
Diatoms
---
This Excel spreadsheet contains five sheets. Four of these sheets (all but “Note”) are necessary for running the SAR R code. The code generates sample-based rarefaction curves across windows, fits them with several SAR models, determines the best fitting model, and calculates environmental and metacommunity properties.

## Description of the Data and file structure:
The sheet “Note” describes each sheet.
The sheet "Taxa" contains species counts in 2278 distinct stream sites.
The sheet "Environment" contains sample ID, latitude, longitude, local physico-chemistry, bioclimatic, and land use data for 2278 distinct stream sites. The local physico-chemistry,  bioclimatic, and land use data are either raw or centered and standardized, the latter with a suffix "CST". 

The  bioclimatic variables are abbreviated as follows in all three datasets (i.e., Diatoms, Insects, and Fish):

bio1 = Annual Mean Temperature (°C × 10)
bio2 = Mean Diurnal Range (Mean of monthly (max temperature − min temperature)) (°C × 10)
bio3 = Isothermality (bio2/bio7) × 100 (%) 
bio4 = Temperature Seasonality (Standard Deviation) (°C × 100)
bio5 = Max Temperature of Warmest Month (°C × 10)
bio6 = Min Temperature of Coldest Month (°C × 10))
bio7 = Temperature Annual Range (bio5 − bio6) (°C × 10)
bio8 = Mean Temperature of Wettest Quarter (°C × 10)
bio9 = Mean Temperature of Driest Quarter (°C × 10)
bio10 = Mean Temperature of Warmest Quarter (°C × 10)
bio11 = Mean Temperature of Coldest Quarter (°C × 10)
bio12 = Annual Precipitation (mm)
bio13 = Precipitation of Wettest Month (mm)
bio14 = Precipitation of Driest Month (mm)
bio15 = Precipitation Seasonality (Coefficient of Variation)
bio16 = Precipitation of Wettest Quarter (mm)
bio17 = Precipitation of Driest Quarter (mm)
bio18 = Precipitation of Warmest Quarter (mm)
bio19 = Precipitation of Coldest Quarter (mm)

The land use variables are given in proportion and abbreviated as follows in all three datasets (i.e., Diatoms, Insects, and Fish):

openWater = Open Water: areas of open water, generally with less than 25% cover of vegetation or soil.

developedOpenSpace = Developed, Open Space: areas with a mixture of some constructed materials, but mostly vegetation in the form of lawn grasses. Impervious surfaces account for less than 20% of total cover. These areas most commonly include large-lot single-family housing units, parks, golf courses, and vegetation planted in developed settings for recreation, erosion control, or aesthetic purposes.

developedLowIntensity = Developed, Low Intensity: areas with a mixture of constructed materials and vegetation. Impervious surfaces account for 20% to 49% percent of total cover. These areas most commonly include single-family housing units.

developedMedIntensity = Developed, Medium Intensity: areas with a mixture of constructed materials and vegetation. Impervious surfaces account for 50% to 79% of the total cover. These areas most commonly include single-family housing units.

developedHighIntensity = Developed High Intensity: highly developed areas where people reside or work in high numbers. Examples include apartment complexes, row houses and commercial/industrial. Impervious surfaces account for 80% to 100% of the total cover.

barrenLand = Barren Land (Rock/Sand/Clay): areas of bedrock, desert pavement, scarps, talus, slides, volcanic material, glacial debris, sand dunes, strip mines, gravel pits and other accumulations of earthen material. Generally, vegetation accounts for less than 15% of total cover.

deciduousForest = Deciduous Forest: areas dominated by trees generally greater than 5 meters tall, and greater than 20% of total vegetation cover. More than 75% of the tree species shed foliage simultaneously in response to seasonal change.

evergreenForest = Evergreen Forest: areas dominated by trees generally greater than 5 meters tall, and greater than 20% of total vegetation cover. More than 75% of the tree species maintain their leaves all year. Canopy is never without green foliage.

mixedForest = Mixed Forest: areas dominated by trees generally greater than 5 meters tall, and greater than 20% of total vegetation cover. Neither deciduous nor evergreen species are greater than 75% of total tree cover.

shrubScrub = Shrub/Scrub: areas dominated by shrubs; less than 5 meters tall with shrub canopy typically greater than 20% of total vegetation. This class includes true shrubs, young trees in an early successional stage or trees stunted from environmental conditions.

grasslandHerbaceous = Grassland/Herbaceous: areas dominated by gramanoid or herbaceous vegetation, generally greater than 80% of total vegetation. These areas are not subject to intensive management such as tilling, but can be utilized for grazing.

pastureHay = Pasture/Hay: areas of grasses, legumes, or grass-legume mixtures planted for livestock grazing or the production of seed or hay crops, typically on a perennial cycle. Pasture/hay vegetation accounts for greater than 20% of total vegetation.

cultivatedCrops = Cultivated Crops: areas used for the production of annual crops, such as corn, soybeans, vegetables, tobacco, and cotton, and also perennial woody crops such as orchards and vineyards. Crop vegetation accounts for greater than 20% of total vegetation. This class also includes all land being actively tilled.

woodyWetlands = Woody Wetlands: areas where forest or shrubland vegetation accounts for greater than 20% of vegetative cover and the soil or substrate is periodically saturated with or covered with water.

emergentHerbaceousWetlands = Emergent Herbaceous Wetlands: areas where perennial herbaceous vegetation accounts for greater than 80% of vegetative cover and the soil or substrate is periodically saturated with or covered with water.


The sheet "Sites by windows" indicates in which window and sub-window each sample is found. The scale (area) of each window and the latitude and longitude of its centroid are also provided.
The sheet “Randomization scheme” contains the window IDs, and the scale (area), the number of sites, and the number of randomizations for each window.

## Sharing/access Information
N/A

# Title of Dataset:
Insects
---
This Excel spreadsheet contains five sheets. Four of these sheets (all but “Note”) are necessary for running the SAR R code. The code generates sample-based rarefaction curves across windows, fits them with several SAR models, determines the best fitting model, and calculates environmental and metacommunity properties.

## Description of the Data and file structure:
The sheet “Note” describes each sheet.
The sheet "Taxa" contains genus counts in 2270 distinct stream sites.
The sheet "Environment" contains sample ID, latitude, longitude, local physico-chemistry, bioclimatic, and land use data for 2270 distinct stream sites. The local physico-chemistry,  bioclimatic, and land use data are either raw or centered and standardized, the latter with a suffix "CST". 
The sheet "Sites by windows" indicates in which window and sub-window each sample is found. The scale (area) of each window and the latitude and longitude of its centroid are also provided.
The sheet “Randomization scheme” contains the window IDs, and the scale (area), the number of sites, and the number of randomizations for each window.

## Sharing/access Information
N/A

# Title of Dataset:
Fish
---
This Excel spreadsheet contains five sheets. Four of these sheets (all but “Note”) are necessary for running the SAR R code. The code generates sample-based rarefaction curves across windows, fits them with several SAR models, determines the best fitting model, and calculates environmental and metacommunity properties.

## Description of the Data and file structure:
The sheet “Note” describes each sheet.
The sheet "Taxa" contains species counts in 2296 distinct stream sites.
The sheet "Environment" contains sample ID, latitude, longitude, local physico-chemistry, bioclimatic, and land use data for 2296 distinct stream sites. The local physico-chemistry,  bioclimatic, and land use data are either raw or centered and standardized, the latter with a suffix "CST". 
The sheet "Sites by windows" indicates in which window and sub-window each sample is found. The scale (area) of each window and the latitude and longitude of its centroid are also provided.
The sheet “Randomization scheme” contains the window IDs, and the scale (area), the number of sites, and the number of randomizations for each window.

## Sharing/access Information
N/A